@@ -2,11 +2,10 @@
 # Given the fact that your VPS is well configured
 # with a correct hostname ans IP, this script will
 # setup DTC in ONCE, by just giving a password that
-# will be set for the root: shell account, MySQL,
-# DTC and phpmyadmin.
+# will be set for the root MySQL user, DTC and phpmyadmin.
+#
 # This will only run on Debian based VPS, it should
-# run well with Etch and Lenny, but it's not tested
-# if using Ubuntu.
+# run well with Squeeze, but it's not tested if using Ubuntu.
 
 set -e
 
@@ -19,13 +18,12 @@ fi
 # Get the password to set using the command line...
 PASSWORD=$1
 
-apt-get update
-apt-get --assume-yes install ssh
-apt-get --force-yes --assume-yes dist-upgrade
+export DEBCONF_FRONTEND=noninteractive
+APTGET="apt-get -o Dpkg::Options::=--force-confnew --force-yes -fuy"
 
-# Use shadow password and set the root pass of the ssh
-shadowconfig on
-( sleep 1; echo ${PASSWORD}; sleep 1; echo ${PASSWORD}; ) | passwd
+apt-get update
+${APTGET} install ssh
+${APTGET} dist-upgrade
 
 # Set the apt to NOT install the recommends, to make it a smaller footprint
 echo "APT{
@@ -42,17 +40,8 @@ MKTEMP="mktemp -t"
 
 SETSEL_FILE=`${MKTEMP} DTC_AUTODEPLOY.XXXXXX` || exit 1
 
-# Set debconf back to Noninteractive, otherwise phpmyadmin is annoying...
-echo "debconf debconf/frontend select Noninteractive
-debconf debconf/frontend seen true
-debconf debconf/priority select medium
-debconf debconf/priority seen true
-debconf debconf-apt-progress/title string fake
-debconf debconf-apt-progress/title seen true
-debconf debconf-apt-progress/preparing string fake
-debconf debconf-apt-progress/preparing seen true" >${SETSEL_FILE}
-debconf-set-selections ${SETSEL_FILE}
-apt-get --force-yes --assume-yes --reinstall install debconf
+#DEBCONF_FRONTEND=noninteractive apt-get --force-yes --assume-yes install squirrelmail squirrelmail-locales
+${APTGET} install squirrelmail squirrelmail-locales
 
 # Copy our selection_config_file template file, and tweak it with correct values
 cp selection_config_file ${SETSEL_FILE}
@@ -64,20 +53,11 @@ sed -i "s/__IP__ADDRESS__/${IP_ADDR}/g" ${SETSEL_FILE}
 # Set the values needed to setup DTC
 debconf-set-selections ${SETSEL_FILE}
 
-# Set the locales, otherwise postinst are printing a bunch of ugly warning messages
-echo "en_US.UTF-8 UTF-8
-en_US ISO-8859-1
-en_US.ISO-8859-15 ISO-8859-15
-" >/etc/locale.gen
-export LANGUAGE="en_US.UTF-8"
-export LANG="en_US.UTF-8"
-export LC_ALL="en_US.UTF-8"
-locale-gen
-apt-get --force-yes --assume-yes install dtc-toaster
+${APTGET} install dtc-toaster
 
-apache2ctl start
-
-# Set debconf back to medium priority, using Dialog
+# Sets back debconf to interactive mode with priority medium,
+# so that the user can install new packages (like roundcube)
+# more comfortably.
 echo "debconf debconf/frontend select Dialog
 debconf debconf/frontend seen true
 debconf debconf/priority select medium
@@ -87,9 +67,10 @@ debconf debconf-apt-progress/title seen true
 debconf debconf-apt-progress/preparing string fake
 debconf debconf-apt-progress/preparing seen true" >${SETSEL_FILE}
 debconf-set-selections ${SETSEL_FILE}
-apt-get --force-yes --assume-yes --reinstall install debconf
+dpkg-reconfigure -f noninteractive debconf
 
 # Finally start the dtc shell installer and we are done!
 /usr/share/dtc/admin/install/install
 
-apache2ctl start
+sleep 2
+invoke-rc.d apache2 restart
